### xyzzy1

a magic trick in adventure

Learn more at https://github.com/radiasoft/xyzzy1.

Documentation: http://xyzzy1.readthedocs.org/en/latest/

#### License

License: http://www.apache.org/licenses/LICENSE-2.0.html

Copyright (c) 2024 RadiaSoft LLC.  All Rights Reserved.
